
;**************************************************************************
;*                    I2C Power Save Clock & Themomether                  *
;**************************************************************************
;**************************************************************************
;*          v 1.30 - 08.06.2014                                           *
;*          based on I2C "MAX clock" v 1.07                               *
;*                                                                        *
;**************************************************************************
;*          Hardw.: PIC16F883 used                                        *
;*          OSC.......: Internal osc. used     POWER.....:   3x1,2V accu  *
;**************************************************************************




;------------------------------------------------------
;device addresses:
;	temperature sensor:	1001 A2 A1 A0 x
;	RTC:			1101  0  0  0 x
;------------------------------------------------------



;	SDA -- SDA (RC4)
;	SCL -- SCL (RC3)

;	RB7 with week pull-up - sommer (RB7 = 0) / winter time (RB7 = 1)


 INCLUDE "P16F886.INC"


_U001			     EQU     B'0010000011000100'		;see Page 206 of Datasheet
_U002			     EQU     B'0011111111111111'		;see Page 207 of Datasheet

;	__CONFIG	_CONFIG1, _DEBUG_OFF & _PLL_EN & _BORV_2_5 & _BOR_OFF & _CP_OFF & _MCLR_DIS & _PWRT_DIS & _WDT_OFF & _INTRC_OSC_NOCLKOUT
;	__CONFIG	_CONFIG2, _VCAP_DIS


	__CONFIG	_CONFIG1, _U001

	__CONFIG	_CONFIG2, _U002

;==========================================================================
;       Variable Definition
;==========================================================================
TIMER1		EQU	H'20'		;delay routine
TIMER2		EQU	H'21'		; "	"	"

;---------------------------------------------------------------------
;---------------------------------------------------------------------

v_maxd1		EQU	H'22'
v_maxd2		EQU	H'23'

v_max_h1	EQU	H'24'
v_max_h2	EQU	H'25'
v_max_m1	EQU	H'26'
v_max_m2	EQU	H'27'
;
v_max_eds	EQU	H'28'		;"external LED display switch" - displaying clock or temperature
;
v_max_c1	EQU	H'29'		;to be displayed on clk/tmp LED display
v_max_c2	EQU	H'2A'		;to be displayed on clk/tmp LED display
v_max_c3	EQU	H'2B'		;to be displayed on clk/tmp LED display
v_max_c4	EQU	H'2C'		;to be displayed on clk/tmp LED display
v_max_c5	EQU	H'2D'		;to be displayed on clk/tmp LED display
;
v_max_i		EQU	H'2E'
;---------------------------------------------------------------------
;---------------------------------------------------------------------
v_vt		EQU	H'2F'
v_tst1		EQU	H'30'		;temperature - char output 1
v_tst2		EQU	H'31'		;temperature - char output 2
v_tst3		EQU	H'32'		;temperature - char output 3
;---------------------------------------------------------------------
;---------------------------------------------------------------------
v_temp1s	EQU	H'33'
v_temp2s	EQU	H'34'

v_t_corr	EQU	H'35'

v_d_mode	EQU	H'36'		;display mode: 01 = display off (day mode) / 02 = display on (night mode)

v_c_t1		EQU	H'37'		;charge timer 1
v_c_t2		EQU	H'38'		;charge timer 2
v_c_t3		EQU	H'39'		;charge timer 3
;---------------------------------------------------------------------
v_power		EQU	H'3A'

v_t_off		EQU	H'3B'

v_max_eds2	EQU	H'3C'

; FREE

;---------------------------------------------------------------------
;---------------------------------------------------------------------
v_hom_bcnt	EQU	H'42'		;blink counter
v_hom_blink	EQU	H'43'		;blink
v_hom_PIR1	EQU	H'44'
v_i2c_add	EQU	H'45'		;I2C address
;-------------------------------------------------------
;Intensity register data
v_dsp_brg	EQU	H'46'

v_x001		EQU	H'47'

v_dots		EQU	H'48'
;-------------------------------------------------------

; FREE --------


;------------------------------------------------
;data for last 5 temperature measurements
v_aa		EQU	H'53'
v_t1		EQU	H'54'
v_t2		EQU	H'55'
v_t3		EQU	H'56'
v_t4		EQU	H'57'
v_t5		EQU	H'58'
;------------------------------------------------

v_ad0		EQU	H'59'		;EEPROM address - lowest 8 bits
v_ad1		EQU	H'5A'		;EEPROM address - highest bits

v_byte		EQU	H'5B'		;data to be written to PCF8574
v_temp1		EQU	H'5C'		;temperature from TMP100 (MSB)
v_temp2		EQU	H'5D'		;temperature from TMP100 (LSB)

v_tempx		EQU	H'5E'		;temperature in dec
v_LED		EQU	H'5F'		;temperature for 8 LEDs

;RTC variables --------------------
v_rtc_d1	EQU	H'60'
v_rtc_d2	EQU	H'61'
v_rtc_m1	EQU	H'62'
v_rtc_m2	EQU	H'63'
v_rtc_y1	EQU	H'64'
v_rtc_y2	EQU	H'65'
v_rtc_y3	EQU	H'66'
v_rtc_y4	EQU	H'67'
v_rtc_h1	EQU	H'68'
v_rtc_h2	EQU	H'69'
v_rtc_n1	EQU	H'6A'
v_rtc_n2	EQU	H'6B'
v_rtc_s1	EQU	H'6C'
v_rtc_s2	EQU	H'6D'

v_rtc_sec	EQU	H'6E'
v_rtc_min	EQU	H'6F'
v_rtc_hrs	EQU	H'70'
v_rtc_wday	EQU	H'71'		;day in the week
v_rtc_day	EQU	H'72'
v_rtc_mnt	EQU	H'73'
v_rtc_year	EQU	H'74'

v_rtc_wd	EQU	H'75'
;---------------------------------
v_tmp1		EQU	H'76'		;temp variable - general usage

v_rtc_t1	EQU	H'77'
v_rtc_t2	EQU	H'78'

v_batt_low_cnt	EQU	H'79'



;==========================================================================

		ORG	0		;Reset vector address
		GOTO	RESET		;goto RESET routine when boot.

;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;
;	       **********************************
;              **  RESET :  main boot routine  **
;              **********************************

RESET		nop
PAGE0
;-----------------------------------------
		bsf	STATUS,RP0
		bsf	STATUS,RP1
		clrf	ANSEL
		clrf	ANSELH

		bcf	STATUS,RP0	;Switch Back to reg. Bank 0
		bcf	STATUS,RP1
;-----------------------------------------

		BSF	STATUS,RP0	;Switch to register bank 1
		MOVLW	B'01011111'	;Set PIC options (See datasheet).
		MOVWF	OPTION_REG	;Write the OPTION register.
		bcf	OPTION_REG,T0CS	;set-up TIMER0 as timer
		bsf	OPTION_REG,PSA	;prescaler NOT for TIMER0
		;
		CLRF	INTCON		;Disable interrupts
		clrf	IOCB

		MOVLW	B'11111000'	;PORTA
		MOVWF	TRISA

		MOVLW	B'11111111'	;PORTB
		MOVWF	TRISB

		MOVLW	B'00011000'	;PORTC
		MOVWF	TRISC

		movlw	B'00001111'
		movwf	WPUB

;set oscilator frequency
;		movlw	B'00010000'	;select 125kHz
;		movwf	OSCCON

		bcf	STATUS,RP0
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------
;set up I2C BUS for communication as a master
		movlw	B'00101000'		;see Datasheet Page 177
;			bit 3-0 SSPM<3:0>: Synchronous Serial Port Mode Select bits
;			1000 = I2C Master mode, clock = FOSC / (4 * (SSPADD+1))
		movwf	SSPCON

;set-up I2C speed
		bsf	STATUS,RP0
		movlw	B'00111111'
		movwf	SSPADD
		clrf	SSPSTAT
		bcf	STATUS,RP0
;----------------------------------------------------------------------------
;----------------------------------------------------------------------------


; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXX       initialization  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
; XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

init_main	clrf	PORTC
		clrf	PORTA
		clrf	v_power
;
		clrf	PIE1
		clrf	PIE2
;
		bcf	INTCON,GIE		;disable all interrupts
;----------------------------------------------------------------------------
		call	rtc_v_init

		movlw	B'00010000'
		movwf	v_dsp_brg

		movlw	H'02'			;night mode --> display on
		movwf	v_d_mode

		clrf	v_max_eds
		call	init_t_hist

		clrf	v_t_off
		clrf	v_max_eds2

;-----------------------------------------------------------------------------
;Watch Dog Timer Initialization

		bsf	STATUS,RP1
		movlw	B'00001100'		;see datasheet Page 221 - Prescaler: "xxx0110x" = 1:2048
		movwf	WDTCON
;
		bsf	WDTCON,D'000'		;start WDT   ---> WDF overflow always after ~15 sec.
;
		bcf	STATUS,RP1

		clrwdt				;clear WDT


;----------- temperature off ? -----------------------------------------------
;
		btfss	PORTB,D'002'
;at power-on the "display on demand" button is pressed => switch off the temperature info
		bsf	v_t_off,D'000'		;temeprature shall NOT be displayed


		movlw	D'050'			;number of required low batt detections to indicate low battery stage
						;it is a total number from start-up / chagre operation (not continuosly detections...)
		movwf	v_batt_low_cnt

; ----------------------------------------------------------------------------
; ----------------------------------------------------------------------------
;                                 MAIN LOOP
; ----------------------------------------------------------------------------
; ----------------------------------------------------------------------------
dctd001		movlw	B'00100000'
		movwf	v_dots

		call	rtc_v_init
		call	rtc_v_init2
;
		bcf	v_power,D'000'		;clear external power flag
;power
		btfsc	PORTB,D'004'
		bsf	v_power,D'000'		;external power is attached
;low battery detection
		btfsc	PORTB,D'006'
		bsf	v_power,D'001'		;low battery detected
;----------------------------------------------------------------------------
		btfsc	v_power,D'000'
		goto	main_c2
;-----------------------------------------------------------
;no external power detected -- clear charging progress flags
		bcf	v_power,D'006'
		bcf	v_power,D'007'

;-----------------------------------------------------------
		btfss	v_power,D'001'
		goto	c55tz

;low power flag activated -- now check the counter
		movf	v_batt_low_cnt,0
		btfsc	STATUS,Z
		goto	c55tz

		bcf	v_power,D'001'
		decf	v_batt_low_cnt,1
;-----------------------------------------------------------
c55tz		btfsc	v_power,D'001'
		clrf	v_t_off			;at low battery - switch on the temperature info
						;instead of temp the "batt" will be shown

;----------------------------------------------------------------------------
;read time data -------------------------
main_c2		movlw	B'11010000'		;RTC = 1101000x
		movwf	v_i2c_add
		call	rtc_i2c_read
		call	rtc_translate

; ------------------------------------------------------
; ------------------------------------------------------
; clock set-up logic
; ------------------------------------------------------
; ------------------------------------------------------
		btfsc	PORTB,D'003'
		goto	main_c3
; set-up enable switch activated
		btfss	v_power,D'000'
		goto	main_c3			;no external power -- no set-up
; external power is attached
		btfss	PORTB,D'007'
		goto	main_c3			;sommer time -- no set-up
; sommer time not active
		goto	clock_setup
; ------------------------------------------------------
; ------------------------------------------------------
; ------------------------------------------------------
main_c3		movf	v_d_mode,0
		xorlw	H'02'
		btfss	STATUS,Z
		goto	mode_off
		goto	mode_on
;--------------------------------------------------------
;day mode -- display is off

mode_off	btfsc	v_power,D'000'
		goto	mode_on			;external power is on
;
		call	max_data_off
		call	init_t_hist
		call	temp_no_value
		call	dr01
		bcf	PORTA,D'002'
		bcf	PORTA,D'001'
		bcf	PORTA,D'000'
		goto	dctd001

;--------------------------------------------------------
;night mode -- display is on

mode_on		call	max_data_full		;clock and temperature display (MAX6959A)
		call	dr01

		btfsc	v_power,D'000'
		goto	batt_ccontrol
;--------------------------------------------------------
		bcf	PORTA,D'002'
		bcf	PORTA,D'001'
		goto	dctd001
;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------
init_t_hist	movlw	H'FF'
		movwf	v_t1
		movwf	v_t2
		movwf	v_t3
		movwf	v_t4
		movwf	v_t5
		return
;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------
;battery charging counter
batt_ccontrol	btfss	v_power,D'007'
		call	init_charge
		btfsc	v_power,D'006'
		goto	chrg_finished
;-----------------------------------------
;battery charging in progress
		bcf	v_power,D'001'		;clear low battery flag
		movlw	D'050'			;init low battery detection counter
		movwf	v_batt_low_cnt

		incf	v_c_t1,1
		btfss	STATUS,Z
		goto	dctd001
		incf	v_c_t2,1
		movf	v_c_t2,0
		xorlw	D'016'			;005 = ~  9 minutes
						;010 = ~ 18 minutes
						;016 = ~ 30 minutes
		btfss	STATUS,Z
		goto	dctd001
;
		clrf	v_c_t1
		clrf	v_c_t2
		incf	v_c_t3,1
		movf	v_c_t3,0
		xorlw	D'020'			;002 x 30 min = ~  1 hrs
						;020 x 30 min = ~ 10 hrs
		btfsc	STATUS,Z
		bsf	v_power,D'006'		;timer border reached
		goto	dctd001
;--------------------------------------------------------
;--------------------------------------------------------
;--------------------------------------------------------
init_charge	bsf	PORTA,D'002'		;switch the red LED on
		bcf	PORTA,D'001'		;switch the green LED off
		bcf	PORTA,D'000'

		clrf	v_c_t1			;clear charging timer 1
		clrf	v_c_t2			;clear charging timer 2
		clrf	v_c_t3			;clear charging timer 3

		bsf	v_power,D'007'		;battery charging timer initialized
		return
;--------------------------------------------------------
;--------------------------------------------------------
;--------------------------------------------------------
;charging is finished
chrg_finished	nop
		bcf	PORTA,D'002'		;switch the red LED off
		bsf	PORTA,D'001'		;switch the green LED on

		bsf	PORTA,D'000'		;disconnect akku
		goto	dctd001
; ----------------------------------------------------------------------------
; ----------------------------------------------------------------------------
;                             End of MAIN LOOP
; ----------------------------------------------------------------------------
; ----------------------------------------------------------------------------

max_data_off	nop

;clear corresponding display variables
		movlw	B'00000000'
		movwf	v_max_c1
		movwf	v_max_c2
		movwf	v_max_c3
		movwf	v_max_c4
		movwf	v_max_c5

		call	max_init_B

		return
;---------------------------------------------------------------------------------------
;---------------------------------------------------------------------------------------
;---------------------------------------------------------------------------------------
;---------------------------------------------------------------------------------------
t_convert2dec	movlw	'0'
		movwf	v_tst1
		movwf	v_tst2
		movwf	v_tst3
;
		clrf	v_maxd1
		clrf	v_maxd2
;
		clrf	v_tempx
;
		movlw	D'255'
		xorwf	v_temp1,0
		btfsc	STATUS,Z
		goto	temp_no_value
;
;--------------------------------------------------------------------------------------------
;correction for the model builed at 26.07.2013 using TMP100 ---------------------------------
;--------------------------------------------------------------------------------------------
		incf	v_temp1,1
;
		movf	v_t_corr,0
		movwf	v_x001
		incf	v_x001,1
;
tc01		decf	v_temp1,1
		decfsz	v_x001,1
		goto	tc01
;--------------------------------------------------------------------------------------------
;--------------------------------------------------------------------------------------------
;--------------------------------------------------------------------------------------------
;
		incf	v_temp1,0		;we convert only MSB now
		movwf	TIMER1			;store "to be converted" value to data location TIMER1
		
t_next		decfsz	TIMER1,1
		goto	t_inc_t
;we are done.....----
		movf	v_tst1,0
		xorlw	'0'
		btfss	STATUS,Z
		return
;
		movlw	' '		;use space instead of very first '0'
		movwf	v_tst1

		return
;---------------------
t_inc_t		nop

		incf	v_tempx,1

		incf	v_tst3,1
;----------------------------------------
		incf	v_maxd2,1
;----------------------------------------
		movf	v_tst3,0
		xorlw	':'
		btfss	STATUS,Z
		goto	t_c_fin
;
		movlw	'0'
		movwf	v_tst3
;----------------------------------------
		clrf	v_maxd2
		incf	v_maxd1,1
;----------------------------------------
		incf	v_tst2,1
		movf	v_tst2,0
		xorlw	':'
		btfss	STATUS,Z
		goto	t_c_fin
;
		movlw	'0'
		movwf	v_tst2
		incf	v_tst1,1

		goto	t_next
;-----------------------------------
t_c_fin		nop		
		goto	t_next

;-----------------------------------
temp_no_value	movlw	'-'
		movwf	v_tst1
		movwf	v_tst2
		movwf	v_tst3

		movlw	D'015'
		movwf	v_maxd1
		movwf	v_maxd2

		return
;-----------------------------------------------------------------------------


;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;	RTC routines
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
rtc_translate	nop

		clrwdt				;clear WDT

		movf	v_rtc_sec,0
		xorlw	D'255'
		btfsc	STATUS,Z
		goto	rtc_v_init				;no RTC device connected

;day
		swapf	v_rtc_day,0
		andlw	B'00000011'
		addlw	'0'
		movwf	v_rtc_d1

		movf	v_rtc_day,0
		andlw	B'00001111'
		addlw	'0'
		movwf	v_rtc_d2


;month
		swapf	v_rtc_mnt,0
		andlw	B'00000001'
		addlw	'0'
		movwf	v_rtc_m1

		movf	v_rtc_mnt,0
		andlw	B'00001111'
		addlw	'0'
		movwf	v_rtc_m2

;year
		movlw	'2'
		movwf	v_rtc_y1
		movlw	'0'
		movwf	v_rtc_y2

		swapf	v_rtc_year,0
		andlw	B'00001111'
		addlw	'0'
		movwf	v_rtc_y3

		movf	v_rtc_year,0
		andlw	B'00001111'
		addlw	'0'
		movwf	v_rtc_y4

;hours
; -------------- sommer time handling ------------------------
; if sommer time is activated (RB7 = 0) just add 1 to the value
		btfsc	PORTB,D'007'
		goto	n_cr
		movf	v_rtc_hrs,0
		andlw	B'00111111'
		xorlw	H'09'
		btfss	STATUS,Z
		goto	st_2
;--------------------------------------------
;we got '09' -> we have to change it to '10'
		movlw	H'10'
		movwf	v_rtc_hrs
		goto	n_cr
;--------------------------------------------
st_2		movf	v_rtc_hrs,0
		andlw	B'00111111'
		xorlw	H'19'
		btfss	STATUS,Z
		goto	st_1
;--------------------------------------------
;we got '19' -> we have to change it to '20'
		movlw	H'20'
		movwf	v_rtc_hrs
		goto	n_cr
;--------------------------------------------
st_1		incf	v_rtc_hrs,1
		movf	v_rtc_hrs,0
		andlw	B'00111111'
		xorlw	H'24'
		btfsc	STATUS,Z
		clrf	v_rtc_hrs
; ------------------------------------------------------------
n_cr		swapf	v_rtc_hrs,0
		andlw	B'00000011'
		movwf	v_max_h1
		addlw	'0'
		movwf	v_rtc_h1

		movf	v_rtc_hrs,0
		andlw	B'00001111'
		movwf	v_max_h2
		addlw	'0'
		movwf	v_rtc_h2

		call	set_brg

;minutes
		swapf	v_rtc_min,0
		andlw	B'00000111'
		movwf	v_max_m1
		addlw	'0'
		movwf	v_rtc_n1

		movf	v_rtc_min,0
		andlw	B'00001111'
		movwf	v_max_m2
		addlw	'0'
		movwf	v_rtc_n2

;seconds
		swapf	v_rtc_sec,0
		andlw	B'00000111'
		addlw	'0'
		movwf	v_rtc_s1

		movf	v_rtc_sec,0
		andlw	B'00001111'
		addlw	'0'
		movwf	v_rtc_s2
;
;day in the week
		movf	v_rtc_wday,0
		xorlw	D'001'
		btfsc	STATUS,Z
		goto	rtc_set_Mo

		movf	v_rtc_wday,0
		xorlw	D'002'
		btfsc	STATUS,Z
		goto	rtc_set_Tu

		movf	v_rtc_wday,0
		xorlw	D'003'
		btfsc	STATUS,Z
		goto	rtc_set_We

		movf	v_rtc_wday,0
		xorlw	D'004'
		btfsc	STATUS,Z
		goto	rtc_set_Th

		movf	v_rtc_wday,0
		xorlw	D'005'
		btfsc	STATUS,Z
		goto	rtc_set_Fr

		movf	v_rtc_wday,0
		xorlw	D'006'
		btfsc	STATUS,Z
		goto	rtc_set_Sa

		movf	v_rtc_wday,0
		xorlw	D'007'
		btfsc	STATUS,Z
		goto	rtc_set_Su
;
		return
;------------------------------------------------------------------
;------------------------------------------------------------------
;------------------------------------------------------------------
;---------------------------------------------------
;"calculate" the birghtness of the display
; we use value '00010000' from 07.00 to 21.59
; and    value '00000000' from 22.00 to 6.59
;
set_brg		btfss	PORTB,D'002'
		goto	button_on

		nop
		movf	v_rtc_hrs,0
		andlw	B'00111111'
		movwf	v_x001
;00
		movf	v_x001,0
		xorlw	B'00000000'
		btfsc	STATUS,Z
		goto	dsp_on
;01
		movf	v_x001,0
		xorlw	B'00000001'
		btfsc	STATUS,Z
		goto	dsp_on
;02
		movf	v_x001,0
		xorlw	B'00000010'
		btfsc	STATUS,Z
		goto	dsp_on
;03
		movf	v_x001,0
		xorlw	B'00000011'
		btfsc	STATUS,Z
		goto	dsp_on
;04
		movf	v_x001,0
		xorlw	B'00000100'
		btfsc	STATUS,Z
		goto	dsp_on
;05
		movf	v_x001,0
		xorlw	B'00000101'
		btfsc	STATUS,Z
		goto	dsp_on
;06
		movf	v_x001,0
		xorlw	B'00000110'
		btfsc	STATUS,Z
		goto	dsp_on
;07
		movf	v_x001,0
		xorlw	B'00000111'
		btfsc	STATUS,Z
		goto	dsp_on
;08
		movf	v_x001,0
		xorlw	B'00001000'
		btfsc	STATUS,Z
		goto	dsp_off
;09
		movf	v_x001,0
		xorlw	B'00001001'
		btfsc	STATUS,Z
		goto	dsp_off
;10
		movf	v_x001,0
		xorlw	B'00010000'
		btfsc	STATUS,Z
		goto	dsp_off
;11
		movf	v_x001,0
		xorlw	B'00010001'
		btfsc	STATUS,Z
		goto	dsp_off
;12
		movf	v_x001,0
		xorlw	B'00010010'
		btfsc	STATUS,Z
		goto	dsp_off
;13
		movf	v_x001,0
		xorlw	B'00010011'
		btfsc	STATUS,Z
		goto	dsp_off
;14
		movf	v_x001,0
		xorlw	B'00010100'
		btfsc	STATUS,Z
		goto	dsp_off
;15
		movf	v_x001,0
		xorlw	B'00010101'
		btfsc	STATUS,Z
		goto	dsp_off
;16
		movf	v_x001,0
		xorlw	B'00010110'
		btfsc	STATUS,Z
		goto	dsp_off
;17
		movf	v_x001,0
		xorlw	B'00010111'
		btfsc	STATUS,Z
		goto	dsp_off
;18
		movf	v_x001,0
		xorlw	B'00011000'
		btfsc	STATUS,Z
		goto	dsp_off
;19
		movf	v_x001,0
		xorlw	B'00011001'
		btfsc	STATUS,Z
		goto	dsp_on
;20
		movf	v_x001,0
		xorlw	B'00100000'
		btfsc	STATUS,Z
		goto	dsp_on
;21
		movf	v_x001,0
		xorlw	B'00100001'
		btfsc	STATUS,Z
		goto	dsp_on
;22
		movf	v_x001,0
		xorlw	B'00100010'
		btfsc	STATUS,Z
		goto	dsp_on
;23
		movf	v_x001,0
		xorlw	B'00100011'
		btfsc	STATUS,Z
		goto	dsp_on
;-------------------------------------
dsp_off		movlw	B'00000000'
		btfsc	v_power,D'000'
		movlw	B'00010000'		;external power is attached
;
		movwf	v_dsp_brg		;set brightness

		movlw	H'01'
		movwf	v_d_mode

		movlw	D'002'
		movwf	v_t_corr
		return
;-------------------------------------
dsp_on		movlw	B'00000000'
		movwf	v_dsp_brg		;set brightness

		movlw	H'02'
		movwf	v_d_mode

		movlw	D'002'
		movwf	v_t_corr
		return
;-------------------------------------
button_on	movlw	B'00010000'
		movwf	v_dsp_brg		;set brightness

		movlw	H'02'
		movwf	v_d_mode

		movlw	D'002'
		movwf	v_t_corr
		return
;------------------------------------------------------------------
;------------------------------------------------------------------
;------------------------------------------------------------------
rtc_set_Mo	movlw	'M'
		movwf	v_rtc_t1
		movlw	'o'
		movwf	v_rtc_t2
		return

rtc_set_Tu	movlw	'T'
		movwf	v_rtc_t1
		movlw	'u'
		movwf	v_rtc_t2
		return

rtc_set_We	movlw	'W'
		movwf	v_rtc_t1
		movlw	'e'
		movwf	v_rtc_t2
		return

rtc_set_Th	movlw	'T'
		movwf	v_rtc_t1
		movlw	'h'
		movwf	v_rtc_t2
		return

rtc_set_Fr	movlw	'F'
		movwf	v_rtc_t1
		movlw	'r'
		movwf	v_rtc_t2
		return

rtc_set_Sa	movlw	'S'
		movwf	v_rtc_t1
		movlw	'a'
		movwf	v_rtc_t2
		return

rtc_set_Su	movlw	'S'
		movwf	v_rtc_t1
		movlw	'u'
		movwf	v_rtc_t2
		return

;-----------------------------------------------------------------------------
rtc_backtrs	nop
;date - day
		movlw	'0'
		subwf	v_rtc_d1,0
		movwf	v_tmp1
		swapf	v_tmp1,1

		movlw	'0'
		subwf	v_rtc_d2,0
		addwf	v_tmp1,0

		movwf	v_rtc_day
;----------------------------------
;date - month
		movlw	'0'
		subwf	v_rtc_m1,0
		movwf	v_tmp1
		swapf	v_tmp1,1

		movlw	'0'
		subwf	v_rtc_m2,0
		addwf	v_tmp1,0

		movwf	v_rtc_mnt
;----------------------------------
;date - year
		movlw	'0'
		subwf	v_rtc_y3,0
		movwf	v_tmp1
		swapf	v_tmp1,1

		movlw	'0'
		subwf	v_rtc_y4,0
		addwf	v_tmp1,0

		movwf	v_rtc_year
;----------------------------------
;date - day in the week - always use 1; and we will see...
		movlw	'0'
		subwf	v_rtc_wd,0
		movwf	v_rtc_wday

;----------------------------------
;time - hours
		movlw	'0'
		subwf	v_rtc_h1,0
		movwf	v_tmp1
		swapf	v_tmp1,1

		movlw	'0'
		subwf	v_rtc_h2,0
		addwf	v_tmp1,0

		movwf	v_rtc_hrs
;----------------------------------
;time - minutes
		movlw	'0'
		subwf	v_rtc_n1,0
		movwf	v_tmp1
		swapf	v_tmp1,1

		movlw	'0'
		subwf	v_rtc_n2,0
		addwf	v_tmp1,0

		movwf	v_rtc_min
;----------------------------------
;time - seconds
		movlw	'0'
		subwf	v_rtc_s1,0
		movwf	v_tmp1
		swapf	v_tmp1,1

		movlw	'0'
		subwf	v_rtc_s2,0
		addwf	v_tmp1,0

		movwf	v_rtc_sec

		return
;-----------------------------------------------------------------------------
rtc_v_init	movlw	'-'
		movwf	v_rtc_d1
		movwf	v_rtc_d2
		movwf	v_rtc_m1
		movwf	v_rtc_m2
		movwf	v_rtc_y1
		movwf	v_rtc_y2
		movwf	v_rtc_y3
		movwf	v_rtc_y4
		movwf	v_rtc_h1
		movwf	v_rtc_h2
		movwf	v_rtc_n1
		movwf	v_rtc_n2
		movwf	v_rtc_s1
		movwf	v_rtc_s2

		movwf	v_rtc_t1
		movwf	v_rtc_t2

		return
;-----------------------------------------------------------------------------
rtc_v_init2	movlw	D'255'
		movwf	v_rtc_sec
		return
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;
; I2C communication routines
;
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

;-----------------------------------------------------------------------------
i2c_start	bsf	STATUS,RP0
		bsf	SSPCON2, SEN
		bcf	STATUS,RP0
		call	d55
		return
;-----------------------------------------------------------------------------
i2c_stop	bsf	STATUS,RP0
		bsf	SSPCON2, PEN
		bcf	STATUS,RP0
		call	d55
		return
;-----------------------------------------------------------------------------
i2c_ack		bsf	STATUS,RP0
		bcf	SSPCON2, ACKDT		;ACK
		bsf	SSPCON2, ACKEN
		bcf	STATUS,RP0
		call	d55
		return
;-----------------------------------------------------------------------------
i2c_not_ack	bsf	STATUS,RP0
		bsf	SSPCON2, ACKDT		;NOT ACK
		bsf	SSPCON2, ACKEN
		bcf	STATUS,RP0
		call	d55
		return
;-----------------------------------------------------------------------------
;output: received byte is in W register
;
i2c_receive	bsf	STATUS,RP0
		bsf	SSPCON2, RCEN
		bcf	STATUS,RP0
		call	d55
		movf	SSPBUF,0
		return
;-----------------------------------------------------------------------------
;input: transmitted byte have to be in W register
;
i2c_send	movwf	SSPBUF
		call	d55		;wait a while
		return
;-----------------------------------------------------------------------------
i2c_restart	bsf	STATUS,RP0
		bsf	SSPCON2, RSEN
		bcf	STATUS,RP0
		call	d55
		return
;-----------------------------------------------------------------------------




;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
; Real Time clock I2C communication routines
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;read current date/time
rtc_i2c_read	nop

;Step 1 - Start condition
		call	i2c_start

;Step 2: addressing the RTC device
		movf	v_i2c_add,0		;get the RTC device address
		andlw	B'11111110'		;set bit 0 to "0" -> write
		call	i2c_send

;Step 3: send memory location
		movlw	B'00000000'		;memory address (= 0)
		call	i2c_send

;Step 4: send STOP condition (stop the write)
		call	i2c_stop

;Step 5: START condition
		call	i2c_start

;Step 6: addressing the RTC device
		movf	v_i2c_add,0		;get the RTC device address
		iorlw	B'00000001'		;set bit 0 to "1" -> read
		call	i2c_send

;-------------------------------------
;Step 7: read data
;7.1 - sec
		call	i2c_receive		;received byte - sec
		movwf	v_rtc_sec
		call	i2c_ack

;7.2 - min
		call	i2c_receive		;received byte - min
		movwf	v_rtc_min
		call	i2c_ack

;7.3 - hours
		call	i2c_receive		;received byte
		movwf	v_rtc_hrs
		call	i2c_ack

;7.4 - day in a week
		call	i2c_receive		;received byte
		movwf	v_rtc_wday
		call	i2c_ack

;7.5 - day
		call	i2c_receive		;received byte
		movwf	v_rtc_day
		call	i2c_ack

;7.6 - month
		call	i2c_receive		;received byte
		movwf	v_rtc_mnt
		call	i2c_ack

;7.7 - year
		call	i2c_receive		;received byte
		movwf	v_rtc_year
		call	i2c_not_ack

;Step 8: send STOP condition (stop the read)
		call	i2c_stop

		return

;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
rtc_i2c_write	nop

;Step 1: Start condition
		call	i2c_start
;
;Step 2: addressing the RTC device

		movf	v_i2c_add,0
		andlw	B'11111110'		;set bit 0 to "0" -> write
		call	i2c_send

;Step 3: send memory location
		movlw	B'00000000'		;memory address (= 0)
		call	i2c_send
;-------------------------------------
;Step 4: write data
;4.1 - sec
		movf	v_rtc_sec,0
		call	i2c_send

;4.2 - min
		movf	v_rtc_min,0
		call	i2c_send

;4.3 - hours
		movf	v_rtc_hrs,0
		call	i2c_send

;4.4 - day in a week
		movf	v_rtc_wday,0
		call	i2c_send

;4.5 - day
		movf	v_rtc_day,0
		call	i2c_send

;4.6 - month
		movf	v_rtc_mnt,0
		call	i2c_send

;4.7 - year
		movf	v_rtc_year,0
		call	i2c_send

;Step 5: send STOP condition (stop the read)
		call	i2c_stop

		return

;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------
; TMP100 I2C communication routines
;-----------------------------------------------------------------------------
;-----------------------------------------------------------------------------

;---------------------------------------------------------------------------------
;read routine for temperature sensor TMP100, LM76 and AT30TSE754
;with pointer setting
;---------------------------------------------------------------------------------


tmp100_read_t1	nop

;1. write the address of required registerto the device
		call	i2c_start

		movf	v_i2c_add,0
		andlw	B'11111110'		;write
		call	i2c_send		;addressing the device

		movlw	B'00000000'		;Register Addess = 00 => temperature register
		call	i2c_send

;2. read the temperature
		call	i2c_restart

		movf	v_i2c_add,0
		iorlw	B'00000001'		;read
		call	i2c_send

		call	i2c_receive		;received byte
		movwf	v_temp1
		call	i2c_ack

		call	i2c_receive		;received byte
		movwf	v_temp2
		call	i2c_not_ack

		call	i2c_stop

		call	store_histt
		call	find_best

		return
;--------------------------------------------------------------------------
;--------------------------------------------------------------------------
;store the value to the history of last 5...
store_histt	nop
;
		movf	v_t4,0
		movwf	v_t5
		movf	v_t3,0
		movwf	v_t4
		movf	v_t2,0
		movwf	v_t3
		movf	v_t1,0
		movwf	v_t2
		movf	v_temp1,0
		movwf	v_t1		;last temperature
		return
;--------------------------------------------------------------------------
;--------------------------------------------------------------------------
;find temperature to be displayed - based on following rules:
;	1. if the two last values (1 and 2) are identical - display the last value; else
;	2. if the last and the second last (1 and 3) are identical - display the last value; else
;	3. if the 2nd and 3rd values are identical - display the second value; else
;	4. if the 2nd and 4th values are identical - display the second value; else
;	5. if the 3rd and 4th values are identical - display the third value; else
;	6. if the 3rd and 5th values are identical - display the third value; else
;	7. display the last value (1)


find_best	nop
;Rule 1
		movf	v_t1,0
		xorwf	v_t2,0
		btfsc	STATUS,Z
		goto	fb_1

;Rule 2
		movf	v_t1,0
		xorwf	v_t3,0
		btfsc	STATUS,Z
		goto	fb_1

;Rule 3
		movf	v_t2,0
		xorwf	v_t3,0
		btfsc	STATUS,Z
		goto	fb_2

;Rule 4
		movf	v_t2,0
		xorwf	v_t4,0
		btfsc	STATUS,Z
		goto	fb_2

;Rule 5
		movf	v_t3,0
		xorwf	v_t4,0
		btfsc	STATUS,Z
		goto	fb_3

;Rule 6
		movf	v_t3,0
		xorwf	v_t5,0
		btfsc	STATUS,Z
		goto	fb_3

;------------------------------------------------
fb_1		movf	v_t1,0
		movwf	v_temp1
		return
;
fb_2		movf	v_t2,0
		movwf	v_temp1
		return
;
fb_3		movf	v_t3,0
		movwf	v_temp1
		return

;--------------------------------------------------------------------------
;--------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

;		*********************************************
;		*               delay routine               *
;		*********************************************

;------------------------------------
d7		MOVLW   D'127'
		MOVWF   TIMER2
DEL_LOOP71	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP72	DECFSZ  TIMER1,F
		GOTO    DEL_LOOP72
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOP71
		return

;------------------------------------

d2		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP2	DECFSZ  TIMER1,F
		GOTO    DEL_LOOP2
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOP1
		return
;------------------------------------
dr2		call	d2
		call	d2
		call	d2
		return
;------------------------------------
dr2c		call	d2
		call	d2
		call	d2

		return
;------------------------------------

dr55		MOVLW   D'002'
		MOVWF   TIMER2
DEL_LOOPb1	MOVLW   D'100'
		MOVWF   TIMER1

DEL_LOOPb2	DECFSZ  TIMER1,F
		GOTO    DEL_LOOPb2
		DECFSZ  TIMER2,F
		GOTO    DEL_LOOPb1
		return

;-------------------------------------------------------------------------------
d55		movlw	D'255'
		movwf	TIMER2
d55_loop	decfsz	TIMER2,F
		goto	d55_loop
		return
;
dr55x		nop
		nop
		nop
		nop
		nop
		nop
		nop
		nop
		nop
		nop
		nop
		nop
		return
;
dr2n		call	d2
		call	d2
		return
;------------------------------------
dr77		call	d2
		return
;------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------


;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
;-----------------------------------------------------------------------------
d57		MOVLW   D'030'
		MOVWF   TIMER2
DEL_LOOP5721	MOVLW   D'255'
		MOVWF   TIMER1
DEL_LOOP5722	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP5722
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP5721
		return
;
dr01s		MOVLW   D'010'
		MOVWF   TIMER2
DEL_LOOP3_1s	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2s	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2s
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1s
		RETURN
;
;----------------------------------------------------------------------------
dr01		call	dr01i
		call	dr01i
		return
;-------------------------------------
dr01i		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP3_1	MOVLW   D'255'
		MOVWF   TIMER1

DEL_LOOP3_2	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP3_2
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP3_1
		RETURN
;------------------------------------------------------------------------------
;------------------------------------------------------------------------------
max_translate	movf	v_max_i,0
		xorlw	D'000'
		btfsc	STATUS,Z
		goto	mc_0

		movf	v_max_i,0
		xorlw	D'001'
		btfsc	STATUS,Z
		goto	mc_1

		movf	v_max_i,0
		xorlw	D'002'
		btfsc	STATUS,Z
		goto	mc_2

		movf	v_max_i,0
		xorlw	D'003'
		btfsc	STATUS,Z
		goto	mc_3

		movf	v_max_i,0
		xorlw	D'004'
		btfsc	STATUS,Z
		goto	mc_4

		movf	v_max_i,0
		xorlw	D'005'
		btfsc	STATUS,Z
		goto	mc_5

		movf	v_max_i,0
		xorlw	D'006'
		btfsc	STATUS,Z
		goto	mc_6

		movf	v_max_i,0
		xorlw	D'007'
		btfsc	STATUS,Z
		goto	mc_7

		movf	v_max_i,0
		xorlw	D'008'
		btfsc	STATUS,Z
		goto	mc_8

		movf	v_max_i,0
		xorlw	D'009'
		btfsc	STATUS,Z
		goto	mc_9

		movlw	B'00000001'
		return

mc_0		movlw	B'01111110'
		return
mc_1		movlw	B'00110000'
		return
mc_2		movlw	B'01101101'
		return
mc_3		movlw	B'01111001'
		return
mc_4		movlw	B'00110011'
		return
mc_5		movlw	B'01011011'
		return
mc_6		movlw	B'01011111'
		return
mc_7		movlw	B'01110000'
		return
mc_8		movlw	B'01111111'
		return
mc_9		movlw	B'01111011'
		return

mc_b		movlw	B'00011111'
		return
mc_A		movlw	B'01110111'
		return
mc_t		movlw	B'00001111'
		return

;------------------------------------------------------------------------------
;------------------------------------------------------------------------------
max_data_full	nop
		incf	v_max_eds,1

		btfsc	v_t_off,D'000'
		bsf	v_max_eds,D'003'		;display only clock

		btfss	v_max_eds,D'003'		;display clock or temperature
		goto	max_data_t
;---------------------------------------------------------------
;display clock
		nop

;read temperature data ------------------
		movlw	B'10010100'		;used I2C address for temperature sensors
		movwf	v_i2c_add
		call	tmp100_read_t1
		call	t_convert2dec

;
;write clock data to v_max_cx variables--------
max_data_clk	movf	v_max_h1,0
		movwf	v_max_i
		call	max_translate
		movwf	v_max_c1
;
		movf	v_max_h2,0
		movwf	v_max_i
		call	max_translate
		movwf	v_max_c2
;
		movf	v_max_m1,0
		movwf	v_max_i
		call	max_translate
		movwf	v_max_c3
;
		movf	v_max_m2,0
		movwf	v_max_i
		call	max_translate
		movwf	v_max_c4

		incf	v_max_eds2,1
		movf	v_dots,0
		movwf	v_max_c5

		btfss	v_max_eds2,D'000'
		clrf	v_max_c5		;blinking dot
;----------------------------------------------
		call	max_init_A
		call	max_data_A
		return
;---------------------------------------------------------------
;display temperature
max_data_t	nop
;
;write temperature data to v_max_cx variables---
		movf	v_maxd1,0
		movwf	v_max_i
		call	max_translate
		movwf	v_max_c1

		movf	v_maxd2,0
		movwf	v_max_i
		call	max_translate
		movwf	v_max_c2

		movlw	B'01100011'
		movwf	v_max_c3
		movlw	B'01001110'
		movwf	v_max_c4
		clrf	v_max_c5
;-----------------------------------------------
		btfsc	v_power,D'001'
		call	disp_batt

		call	max_init_A
		call	max_data_A
		return
;------------------------------------------------------------------------------
disp_batt	call	mc_b
		movwf	v_max_c1
		call	mc_A
		movwf	v_max_c2
		call	mc_t
		movwf	v_max_c3
		call	mc_t
		movwf	v_max_c4
		return
;------------------------------------------------------------------------------
;------------------------------------------------------------------------------
;------------------------------------------------------------------------------
;----------------------------------------------------------------------------------
;----------------------------------------------------------------------------------
max_init_A	call	i2c_start
;
;Step 2: addressing the MAX6959A device
		movlw	B'01110000'		;MAX6959A = 0111000x --- R/-W = 0 (write)
		call	i2c_send

;Step 3 - write command
		movlw	H'01'			;first register: decode mode register address
		call	i2c_send

;Decode mode data
		movlw	B'00000000'		;no decode used
		call	i2c_send

;Intensity register data
		movlw	B'00000000'
		btfss	v_power,D'001'		;batter low reached
		movf	v_dsp_brg,0
		call	i2c_send

;data for scan limit
		movlw	B'00000011'		;value for scan limit - all segments
		call	i2c_send

;data for config reg.
		movlw	B'00000011'		;value for config register
		call	i2c_send

;STOP condition
		call	i2c_stop

		return
;----------------------------------------------------------------------------------
;----------------------------------------------------------------------------------
max_init_B	call	i2c_start
;
;Step 2: addressing the MAX6959A device
		movlw	B'01110000'		;MAX6959A = 0111000x --- R/-W = 0 (write)
		call	i2c_send

;Step 3 - write command
		movlw	H'01'			;first register: decode mode register address
		call	i2c_send

;Decode mode data
		movlw	B'00000000'		;no decode used
		call	i2c_send

;Intensity register data
		movf	v_dsp_brg,0
		call	i2c_send

;data for scan limit
		movlw	B'00000011'		;value for scan limit - all segments
		call	i2c_send

;data for config reg.
		movlw	B'00000010'		;value for config register -- shut down mode
		call	i2c_send

;STOP condition
		call	i2c_stop

		return
;--------------------------------------------------------------------------
;--------------------------------------------------------------------------
;------------------------------------------------------------------------------
;------------------------------------------------------------------------------
;display clock/temp
max_data_A	call	i2c_start
;
;Step 2: addressing the MAX6959A device
		movlw	B'01110000'		;MAX6959A = 0111000x --- R/-W = 0 (write)
		call	i2c_send

;Step 3 - write register address (Page 9 of datasheet)
		movlw	H'20'			;Digit0
		call	i2c_send

;Step 4 - data1 - hrs1
		movf	v_max_c1,0
		xorlw	B'01111110'
		btfss	STATUS,Z
		goto	a355
		movlw	B'00000000'		;do not display "0" as first character
		goto	a356
a355		movf	v_max_c1,0
a356		nop
		call	i2c_send

;Step 4 - data2 - hrs2
		movf	v_max_c2,0
		call	i2c_send

;Step 4 - data3 - min1
		movf	v_max_c3,0
		call	i2c_send

;Step 4 - data4 - min2
		movf	v_max_c4,0
		call	i2c_send

;Step 4 - data5 - "dots"
		movf	v_max_c5,0
		call	i2c_send

;STOP condition
		call	i2c_stop

		return

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------


clock_setup	nop

		movlw	B'11110000'
		movwf	v_dots

		clrf	v_rtc_sec
		bcf	v_rtc_min,D'007'

		call	rtc_translate

		clrwdt				;clear WDT
		call	max_data_clk

		call	d77x

		btfss	PORTB,D'000'
		call	inc_min

		btfss	PORTB,D'001'
		call	inc_hrs


		btfss	PORTB,D'003'
		goto	clock_setup

		call	rtc_i2c_write
		goto	dctd001
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
inc_min		incf	v_rtc_min,1
		movf	v_rtc_min,0
		andlw	H'0F'
		xorlw	H'0A'
		btfss	STATUS,Z
		return

		movf	v_rtc_min,0
		xorlw	H'5A'
		btfsc	STATUS,Z
		goto	clr_min

		movlw	D'006'
		addwf	v_rtc_min,1
		return

clr_min		clrf	v_rtc_min

		return
;---------------------------------------------------------------------------
inc_hrs		incf	v_rtc_hrs,1
		movf	v_rtc_hrs,0
		xorlw	H'24'
		btfsc	STATUS,Z
		goto	clr_hrs

		movf	v_rtc_hrs,0
		andlw	H'0F'
		xorlw	H'0A'
		btfss	STATUS,Z
		return

		movlw	D'006'
		addwf	v_rtc_hrs,1
		return

clr_hrs		clrf	v_rtc_hrs

		return
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------


d55x		movlw	D'255'
		movwf	TIMER2
d55x_loop	decfsz	TIMER2,F
		goto	d55x_loop
		return

d77x		MOVLW   D'255'
		MOVWF   TIMER2
DEL_LOOP7721	MOVLW   D'255'
		MOVWF   TIMER1
DEL_LOOP7722	DECFSZ  TIMER1,F
                GOTO    DEL_LOOP7722
                DECFSZ  TIMER2,F
                GOTO    DEL_LOOP7721
		return

d78x		call	d77x
		call	d77x
		return


;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

		END